@@ -432,7 +432,7 @@ void Glossary::add_entry(Glossary::pair_type& pair, int no_overwrite)
 
 
 /// define one value for the key at specified index: `key[inx]=val`.
-void Glossary::define(key_type const& key, size_t inx, const std::string& arg)
+void Glossary::define(key_type const& key, const std::string& arg, size_t inx)
 {
     std::string val = Tokenizer::trim(arg);
     map_type::iterator w = mTerms.find(key);
@@ -483,7 +483,7 @@ void Glossary::add_value(key_type const& key, const std::string& arg)
  */
 void Glossary::define(key_type const& key, const std::string& rhs)
 {
-    define(key, 0, rhs);
+    define(key, rhs, 0);
 }
 
 
