@@ -66,19 +66,19 @@ void load_fiber_classes(py::module_ &m) {
         .def("abscissaEnd",  [](Chain * chn, int a) {return chn->abscissaPoint((FiberEnd)a);})
         .def("abscissaFrom",  [](Chain * chn, real dis, int a) {return chn->abscissaFrom(dis,(FiberEnd)a);})
         .def("someAbscissa",  [](Chain * chn, real dis, int a, int mod, real alf) {return chn->someAbscissa(dis,(FiberEnd)a, mod, alf);})
-        .def("posM",  [](Chain * chn, real a) {return to_numpy(chn->posM(a));})
-        .def("pos",  [](Chain * chn, real a) {return to_numpy(chn->pos(a));})
+        .def("posM",  [](Chain * chn, real a) {return to_numpy(chn->posM(a));}, PYOWN)
+        .def("pos",  [](Chain * chn, real a) {return to_numpy(chn->pos(a));}, PYOWN)
         .def("posFrom",  [](Chain * chn, real a, int ref) {return chn->posFrom(a,(FiberEnd)ref);})
-        .def("posMiddle",  [](Chain * chn) {return to_numpy(chn->posMiddle());})
-        .def("posEnd",  [](Chain * chn, int end) {return to_numpy(chn->posEnd((FiberEnd)end));})
-        .def("posEndP",  [](Chain * chn) {return to_numpy(chn->posEndP());})
-        .def("posEndM",  [](Chain * chn) {return to_numpy(chn->posEndM());})
-        .def("netForceEndM",  [](Chain * chn) {return to_numpy(chn->netForceEndM());})
-        .def("netForceEndP",  [](Chain * chn) {return to_numpy(chn->netForceEndP());})
+        .def("posMiddle",  [](Chain * chn) {return to_numpy(chn->posMiddle());}, PYOWN)
+        .def("posEnd",  [](Chain * chn, int end) {return to_numpy(chn->posEnd((FiberEnd)end));}, PYOWN)
+        .def("posEndP",  [](Chain * chn) {return to_numpy(chn->posEndP());}, PYOWN)
+        .def("posEndM",  [](Chain * chn) {return to_numpy(chn->posEndM());}, PYOWN)
+        .def("netForceEndM",  [](Chain * chn) {return to_numpy(chn->netForceEndM());}, PYOWN)
+        .def("netForceEndP",  [](Chain * chn) {return to_numpy(chn->netForceEndP());}, PYOWN)
         .def("projectedForceEndM",  [](Chain * chn) {return chn->projectedForceEndM();})
         .def("projectedForceEndP",  [](Chain * chn) {return chn->projectedForceEndP();})
         .def("projectedForceEndM",  [](Chain * chn, int end) {return chn->projectedForceEnd((FiberEnd) end);})
-        .def("avgDirection",  [](Chain * chn) {return to_numpy(chn->avgDirection());})
+        .def("avgDirection",  [](Chain * chn) {return to_numpy(chn->avgDirection());}, PYOWN)
         .def("segmentation",  [](Chain * chn) {return chn->segmentation();})
         .def("flipChainPolarity",  [](Chain * chn) {return chn->flipChainPolarity();})
         .def("curvature",  [](Chain * chn, unsigned p) {return chn->curvature(p);})
@@ -101,8 +101,8 @@ void load_fiber_classes(py::module_ &m) {
         .def("leftoverMobility",  [](Mecafil * mec) {return mec->leftoverMobility();});
     
     py::class_<Fiber,Mecafil>(m, "Fiber")
-        .def("points",  [](Fiber * fib) {return get_obj_points(fib);})
-        .def("toFiber",  [](Object * obj) {return Fiber::toFiber(obj);},  py::return_value_policy::reference)
+        .def("points",  [](Fiber * fib) {return get_obj_points(fib);}, PYOWN)
+        .def("toFiber",  [](Object * obj) {return Fiber::toFiber(obj);}, PYREF)
         .def("nbPoints",  [](Fiber * fib) {return fib->nbPoints();})
 		.def("setDragCoefficient", &Fiber::setDragCoefficient)
 		.def("flipHandsPolarity", &Fiber::flipHandsPolarity)
@@ -127,7 +127,7 @@ void load_fiber_classes(py::module_ &m) {
 		.def("updateHands",  &Fiber::updateHands) 
 		.def("detachHands",  &Fiber::detachHands) 
 		.def("sortHands",  &Fiber::sortHands) 
-		.def("firstHand",  &Fiber::firstHand, py::return_value_policy::reference) 
+		.def("firstHand",  &Fiber::firstHand, PYREF) 
         .def("nbHandsInRange",  [](Fiber * fib, real amin, real amax, int end) {return fib->nbHandsInRange(amin, amax, static_cast<FiberEnd>(end));})
 		.def("nbHandsNearEnd",  [](Fiber * fib, real len, int end) {return fib->nbHandsNearEnd(len, static_cast<FiberEnd>(end));})
         .def("__next__", [](const Fiber * fib) {return fib->next();});
@@ -189,18 +189,18 @@ void load_fiber_classes(py::module_ &m) {
         .def("freshAssemblyP",  [](DynamicFiber * fib) {return fib->freshAssemblyP();});
 
     py::class_<ClassicFiberProp,FiberProp>(m, "ClassicFiberProp")
-		.def("growing_speed",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->growing_speed, 1, 2); })
-		.def("growing_off_speed",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->growing_off_speed, 1, 2);})
-		.def("growing_force",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->growing_force, 1, 2);})
-		.def("shrinking_speed",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->shrinking_speed, 1, 2);})
-		.def("catastrophe_rate",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->catastrophe_rate, 1, 2);})
-		.def("catastrophe_rate_stalled",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->catastrophe_rate_stalled, 1, 2);});
+		.def("growing_speed",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->growing_speed, 1, 2); }, PYOWN)
+		.def("growing_off_speed",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->growing_off_speed, 1, 2);}, PYOWN)
+		.def("growing_force",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->growing_force, 1, 2);}, PYOWN)
+		.def("shrinking_speed",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->shrinking_speed, 1, 2);}, PYOWN)
+		.def("catastrophe_rate",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->catastrophe_rate, 1, 2);}, PYOWN)
+		.def("catastrophe_rate_stalled",  [](ClassicFiberProp * prop) {return to_numpy_raw(prop->catastrophe_rate_stalled, 1, 2);}, PYOWN);
 	
 	py::class_<DynamicFiberProp,FiberProp>(m, "DynamicFiberProp")
-		.def("growing_speed",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->growing_speed, 1, 2); })
-		.def("growing_off_speed",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->growing_off_speed, 1, 2);})
-		.def("growing_force",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->growing_force, 1, 2);})
-		.def("shrinking_speed",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->shrinking_speed, 1, 2);});
+		.def("growing_speed",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->growing_speed, 1, 2); }, PYOWN)
+		.def("growing_off_speed",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->growing_off_speed, 1, 2);}, PYOWN)
+		.def("growing_force",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->growing_force, 1, 2);}, PYOWN)
+		.def("shrinking_speed",  [](DynamicFiberProp * prop) {return to_numpy_raw(prop->shrinking_speed, 1, 2);}, PYOWN);
 	
 	py::class_<GrowingFiber,Fiber>(m, "GrowingFiber");
 	py::class_<GrowingFiberProp,FiberProp>(m, "GrowingFiberProp");
