@@ -21,12 +21,12 @@ void load_object_classes(py::module_ &m) {
 		.def("erase_all",  [](ObjectSet * set) {return set->erase() ;})
 		.def("size",  [](ObjectSet * set) {return set->size() ;})
 		.def("__len__",  [](ObjectSet * set) {return set->size() ;})
-		.def("first",  [](ObjectSet * set) {return set->first() ;}, py::return_value_policy::reference)
-		.def("last",  [](ObjectSet * set) {return set->last() ;}, py::return_value_policy::reference)
+		.def("first",  [](ObjectSet * set) {return set->first() ;}, PYREF)
+		.def("last",  [](ObjectSet * set) {return set->last() ;}, PYREF)
 		.def("findID",  [](ObjectSet * set, int n) 
-			{return set->findID((ObjectID) n) ;}, py::return_value_policy::reference)
+			{return set->findID((ObjectID) n) ;}, PYREF)
 		.def("findObject",  [](ObjectSet * set, Property * p)
-			{return set->findObject(p) ;}, py::return_value_policy::reference)
+			{return set->findObject(p) ;}, PYREF)
 		.def("__getitem__",[](ObjectSet * set, int i) {
 				int s = set->size();
                 if (i<0) {i+=s;} // Python time negative indexing
@@ -39,16 +39,16 @@ void load_object_classes(py::module_ &m) {
 					obj = obj->next(); // Maybe objectSet should derive from std::vect ?
 				}
 				return obj;
-             }, py::return_value_policy::reference);
+             }, PYREF);
      
      /// Python interface to Organizer
     py::class_<Object>(m, "Object")
         .def("reference",  [](Object * obj) {return obj->reference() ;})
-        .def("property",  [](Object * obj) {return obj->property() ;}, py::return_value_policy::reference)
-        .def("position", [](const Object * obj) {return to_numpy(obj->position());})
-        .def("next",  [](Object * obj) {return obj->next() ;}, py::return_value_policy::reference)
-		.def("__next__",  [](Object * obj) {return obj->next() ;}, py::return_value_policy::reference)
-        .def("prev",  [](Object * obj) {return obj->prev() ;}, py::return_value_policy::reference)
+        .def("property",  [](Object * obj) {return obj->property() ;}, PYREF)
+        .def("position", [](const Object * obj) {return to_numpy(obj->position());}, PYOWN)
+        .def("next",  [](Object * obj) {return obj->next() ;}, PYREF)
+		.def("__next__",  [](Object * obj) {return obj->next() ;}, PYREF)
+        .def("prev",  [](Object * obj) {return obj->prev() ;}, PYREF)
         .def("id",  [](const Object * obj) {return obj->identity();})
         .def("tag",  &Object::tag)
         .def("points", [](const Object * obj) {return pyarray();});
@@ -63,6 +63,6 @@ void load_object_classes(py::module_ &m) {
 				}
 				Object * obj = lis[i];
 				return obj;
-             }, py::return_value_policy::reference)
+             }, PYREF)
         .def("__len__", [](const ObjectList &v) { return v.size(); });
 }
