@@ -25,112 +25,59 @@ class Organizer;
 
 void void_callback(void) {};
 
+/**
+ @defgroup PyCytosim PyCytosim
+  A group of classes and functions to facilitate usage of cytosim in python
+   
+ */
 
-class PythonParser : public Parser
-{
-public:
-        
-    /// construct a Parser with given permissions
-    PythonParser(Simul& simul) :Parser(simul,  0, 1, 0, 0, 0) {
-        // Has not been loaded yet
-        is_loaded = 0;
-        // Has not been saved yet
-        is_saved = 0;
-        // Creating a SimThread, maybe
-        sim = &simul;
-    }
+/**
+ @defgroup PyUtilities Utilities
+  A group functions to facilitate usage of cytosim in python
+   
+    @ingroup PyCytosim
+ */
 
-    /// activates the parser (from existing sim)
-    void activate(std::string & input, SimThread * existing_thread) {
-        thread = existing_thread;
-        //thread->start();
-        reader.openFile(input);
-        is_loaded = 1;
-    }
-
-    /// activates the parser (from existing sim)
-    void activate(std::string & input) {
-        thread = new SimThread(*sim, &void_callback);
-        //thread->start();
-        reader.openFile(input);
-        is_loaded = 1;
-    }
-    
-    /// activates the parser (new sim)
-    void activate(SimThread * existing_thread) {
-        Parser::readConfig();
-        thread = existing_thread;
-        thread->start();
-        is_loaded = 2;
-    }
-    
-    /// activates the parser (new sim)
-    void activate() {
-        Parser::readConfig();
-        thread = new SimThread(*sim, &void_callback);
-        thread->start();
-        is_loaded = 2;
-    }
-    
-    /// A framereader
-    FrameReader reader;
-    
-    /// Check if simulation is loaded
-    int is_loaded ;
-    
-    /// A thread
-    SimThread * thread;
-    
-    /// Has the simulation been saved 
-    bool is_saved ;
-    
-    /// is the simulation
-    Simul * sim;
-    
-    /// Loads the simulation at a given time
-    int load(int fr) {
-        int loader = 1;
-        if (is_loaded == 1) {
-            try 
-            {
-                //loader = thread->loadFrame(fr);
-                loader = reader.loadFrame(*sim,fr);
-                if (loader!=0) {
-                    std::clog << "Unable to load frame " << fr << ". Maybe frame does not exist." << std::endl;
-                } 
-                    
-            }
-            catch( Exception & e )
-            {
-                std::clog << "Aborted: " << e.what() << '\n';
-            }
-        }
-        else{
-            std::clog << "Simulation not loaded : use cytosim.open() first" << std::endl;
-        }
-        
-        return loader;
-    }
-    
-    int next() {
-        return reader.loadNextFrame(*sim);
-    }
-};
 
 /// ObjGroup : a vector of objects of same type having the same property
+/** 
+ Behaves mostly as a python list of objects of the same type :
+
+[python]$ `fiber_0 = group[0]` \n
+[python]$ `for fiber in group:  print(fiber.points())`
+  
+ Also contains a pointer the properties of this group :
+  
+[python]$ `prop = group.prop`
+
+ @ingroup PyCytosim
+ */
 template<typename Obj, typename Prp> 
 class ObjGroup : public std::vector<Obj*>{
-    public:
+public:
+    /// The property associated to the group's objects
     Prp * prop;
     ObjGroup() = default;
+    /// Creator \private
     ObjGroup(Prp * p) : ObjGroup() {prop = p ;};
     ~ObjGroup() = default;
 };
 
-/// ObjMap : a map <string, ObjGroup>
+/// ObjMap : a map between a string and and ObjGroup  \private
+/** 
+ Behaves as a python dictionnary associating a name to an ObjGroup of the same category.
+  
+[python]$ `actin_fibers = objmap["actin"]`
+  
+[python]$ `microtubules = objmap["microtubules"]`
+ @ingroup PyCytosim
+ */
 template<typename Obj, typename Prp> 
 using ObjMap = std::map<std::string,ObjGroup<Obj,Prp>> ;
 
+/// ObjVec : a vec <Obj*>
+template<typename Obj> 
+using ObjVec = std::vector<Obj*> ;
 
 /// Distribute the objects (pointers) in the groups and in the dict.
 template<typename Obj, typename Prp, typename Set> 
@@ -189,13 +136,24 @@ void distribute_objects_wID(Simul * sim, py::dict & objects, ObjMap<Obj,Prp> map
     }
 }
 
+/// declare_group() : creates a python interface for an ObjGroup
+/// Unused for now, but should be used to benefit of pybind11's stl containers interface
+template<typename Group, typename Obj>
+auto declare_group(py::module &mod, Group group, std::vector<Obj*> gg , std::string name) { 
+        py::class_<std::vector<Obj*>  >(mod, ("Vector"+name).c_str(), 
+                    "Behaves as a list of objects ");
+        return py::class_<Group, std::vector<Obj*>  >(mod, (name+"Group").c_str(),
+                    "Behaves as a list of objects with the same properties")
+            .def_readwrite("prop",   &Group::prop , PYREF);
+}
+
 /// declare_group() : creates a python interface for an ObjGroup
 template<typename Group>
 auto declare_group(py::module &mod, Group group, std::string name) { 
         return py::class_<Group>(mod, name.c_str(),  "Behaves as a list of objects with the same properties")
             .def("__len__", [](const Group &v) { return v.size(); })
             .def("size", &Group::size)
-            .def_readwrite("prop",   &Group::prop , py::return_value_policy::reference)
+            .def_readwrite("prop",   &Group::prop , PYREF)
             .def("__iter__", [](Group &v) {
                 return py::make_iterator(v.begin(), v.end());
             }, py::keep_alive<0, 1>())
@@ -206,56 +164,88 @@ auto declare_group(py::module &mod, Group group, std::string name) {
                          throw py::index_error();
                      }
                      return v[i];
-                 }, py::return_value_policy::reference);
+                 }, PYREF);
 }
 
 
-/// A time frame ; basically a wrapper around a object dictionnary
-// This would need to be better done
+/// A python-only class to facilitate the handling of the current state of the simulation
+/** 
+ Frame behaves mostly as a python dictionnary of (name, ObjGroup )
+
+ A frame should be updated after a timestep is run, or when a new Frame is loaded
+  
+ [python]$ `actin_fibers = frame["actin"]`
+   
+
+ @ingroup PyCytosim
+ */
 class Frame 
 {
 public:
-        /// An Objectmap is map of  (string,objectgroup)
+        // ObjMaps are maps of (string,objectgroup)
+        
+        /// All fibers \private
         ObjMap<Fiber,FiberProp> fibers;
+        
+        /// All solids \private
         ObjMap<Solid,SolidProp> solids;
+        
+        /// All beads \private
         ObjMap<Bead,BeadProp> beads;
+        
+        /// All spheres \private
         ObjMap<Sphere,SphereProp> spheres;
+        
+        /// All organizers \private
         ObjMap<Organizer,Property> organs;
+        
+        /// All spaces \private
         ObjMap<Space,SpaceProp> spaces;
+        
+        /// All couples \private
         ObjMap<Couple,CoupleProp> couples;
+        
+        /// All singles \private
         ObjMap<Single,SingleProp> singles;
 
-        // Time of the frame
+        /// Current time
         real time;
+        
+        /// Index of the timeframe (if loaded from a replay)
         int index;
+        
+        /// Whether the simulation is loaded from replay
         int loaded;
         
-        /// pointer to simul
+        /// pointer to the current instance of Simul
         Simul * simul;
         
-        /// pointer to parser
-        //PythonParser * parser;
-        
-        /// The party zone
+        /// A python dictionary of (name, ObjMap) \private
         py::dict objects;
         
         /// Default constr and destrc
-        Frame(PythonParser & pyParse) {
+        //Frame(PythonParser & pyParse) {
             //parser = &pyParse;
-            simul = pyParse.sim;
-            update();
-        }
+        //    simul = pyParse.sim;
+        //    update();
+        //}
         
-        /// Default constr and destrc
+        /// Default constr and destrc \private
         Frame(Simul * sim) {
             simul = sim;
             update();
         }
         
-        
+        /// Loads a given timeframe (if simulation is loaded from replay)
         void load(int t) {
-            
         }
+        
+        /// Updates the frame to the current state of the simulation
+        /**
+         * @brief  Updates the simulations objects stored in the frame.
+         *
+         * This is important if objects have been added or deleted !
+         */
         void update() {
             std::vector<std::string> categories = std::vector<std::string>{"aster","nucleus","bundle","fake"};
             //extern std::vector<std::string>  categories;
@@ -278,10 +268,157 @@ public:
             loaded = 1;
         };
         
+        
+        /// Default constructor \private
         Frame() = default;
         ~Frame() = default;
 };
 
 
 
+
+/// A wrapper around Cytosim's Parser to facilitate python interfacing
+/** 
+ PythonParser is A wrapper around Cytosim's Parser to facilitate python interfacing.
+ There should be a single python parser bound to a simulation.
+   
+
+ @ingroup PyCytosim
+ */
+class PythonParser : public Parser
+{
+public:
+        
+    /// construct a Parser with given permissions \private
+    PythonParser(Simul& simul) :Parser(simul,  0, 1, 0, 0, 0) {
+        // Has not been loaded yet
+        is_loaded = 0;
+        // Has not been saved yet
+        is_saved = 0;
+        // Creating a SimThread, maybe
+        sim = &simul;
+    }
+
+    /// A utility function to add objects to the simulation 
+    /**
+     * @brief Adds objects ; takes a variable number of arguments.
+     *  - name : a string with the name of the objects to add
+     *  - (optional) number : a number of objects to add (default : 1)
+     *  - (optional) specs : a string, containing specification on the object to add (default : "")
+     * 
+     * Example :
+     * 
+     * [python]$ `fibers = parser.add("actin", 1, "length = 2")`
+     * @param name ,( number ,( specs )) 
+     * @return Returns a list of objects
+     
+     */
+    ObjectList add(py::args args) {
+
+        std::string name = "";
+        std::string how = "";
+        int many = 1;
+        int nargs = args.size();
+        
+        if (nargs>0) {
+            name = py::cast<std::string>(args[0]);
+        }
+        if (nargs>1) {
+            many = py::cast<int>(args[1]);
+        }
+        if (nargs>2) {
+            how = py::cast<std::string>(args[2]);
+        }
+        
+        Property const* pp = sim->properties.find_or_die(name);    
+        Glossary glos = Glossary(how);
+        
+        return Interface::execute_new(pp->category(), name, glos, many);
+    }
+
+
+    /// Returns the current Frame
+    Frame frame() {
+        return Frame(sim);
+    }
+    
+    /// Pointer to the current instance of FrameReader
+    FrameReader reader;
+    
+    /// Check if simulation is loaded \private
+    int is_loaded ;
+    
+    /// Returns the current instance of SimThread
+    SimThread * thread;
+    
+    /// Informs wether the simulation has been saved \private
+    bool is_saved ;
+    
+    /// Pointer to the current instance of Simul
+    Simul * sim;
+
+    /// Loads the simulation at a given timeframe (only for simulation replay)
+    int load(int fr) {
+        int loader = 1;
+        if (is_loaded == 1) {
+            try 
+            {
+                //loader = thread->loadFrame(fr);
+                loader = reader.loadFrame(*sim,fr);
+                if (loader!=0) {
+                    std::clog << "Unable to load frame " << fr << ". Maybe frame does not exist." << std::endl;
+                } 
+                    
+            }
+            catch( Exception & e )
+            {
+                std::clog << "Aborted: " << e.what() << '\n';
+            }
+        }
+        else{
+            std::clog << "Simulation not loaded : use cytosim.open() first" << std::endl;
+        }
+        
+        return loader;
+    }
+    
+    /// Loads next frame of simulation (only for simulation replay)
+    int next() {
+        return reader.loadNextFrame(*sim);
+    }
+    
+    /// activates the parser (from existing sim) \private
+    void activate(std::string & input, SimThread * existing_thread) {
+        thread = existing_thread;
+        //thread->start();
+        reader.openFile(input);
+        is_loaded = 1;
+    }
+
+    /// activates the parser (from existing sim) \private
+    void activate(std::string & input) {
+        thread = new SimThread(*sim, &void_callback);
+        //thread->start();
+        reader.openFile(input);
+        is_loaded = 1;
+    }
+    
+    /// activates the parser (new sim) \private
+    void activate(SimThread * existing_thread) {
+        Parser::readConfig();
+        thread = existing_thread;
+        thread->start();
+        is_loaded = 2;
+    }
+    
+    /// activates the parser (new sim) \private
+    void activate() {
+        Parser::readConfig();
+        thread = new SimThread(*sim, &void_callback);
+        thread->start();
+        is_loaded = 2;
+    }
+    
+};
+
 #endif
