@@ -71,7 +71,7 @@ auto load_simul_classes(py::module_ &m) {
         .def("number", &Property::number)
         .def("renumber", &Property::renumber)
         .def("clear", &Property::clear)
-        .def("clone", &Property::clone, py::return_value_policy::reference);
+        .def("clone", &Property::clone, PYREF);
         
         
     
@@ -85,19 +85,19 @@ auto load_simul_classes(py::module_ &m) {
 	
     
     auto pysim = py::class_<Simul>(m, "Simul")
-        .def("frame",  [](Simul * sim) {return Frame(sim);}, py::return_value_policy::move)
-        .def_readwrite("prop",   &Simul::prop , py::return_value_policy::reference)
-        .def_readwrite("sMeca",   &Simul::sMeca , py::return_value_policy::reference)
-        .def_readwrite("properties",   &Simul::properties , py::return_value_policy::reference)
-		.def_readonly("spaces",   &Simul::spaces , py::return_value_policy::reference)
-        .def_readonly("fields",   &Simul::fields , py::return_value_policy::reference)
-        .def_readonly("fibers",   &Simul::fibers , py::return_value_policy::reference)
-        .def_readonly("spheres",   &Simul::spheres , py::return_value_policy::reference)
-        .def_readonly("beads",   &Simul::beads , py::return_value_policy::reference)
-        .def_readonly("solids",   &Simul::solids , py::return_value_policy::reference)
-        .def_readonly("couples",   &Simul::couples , py::return_value_policy::reference)
-        .def_readonly("singles",   &Simul::singles , py::return_value_policy::reference)
-        .def_readonly("organizers",   &Simul::organizers , py::return_value_policy::reference)
+        .def("frame",  [](Simul * sim) {return Frame(sim);}, PYMOV)
+        .def_readwrite("prop",   &Simul::prop , PYREF)
+        .def_readwrite("sMeca",   &Simul::sMeca , PYREF)
+        .def_readwrite("properties",   &Simul::properties , PYREF)
+		.def_readonly("spaces",   &Simul::spaces , PYREF)
+        .def_readonly("fields",   &Simul::fields , PYREF)
+        .def_readonly("fibers",   &Simul::fibers , PYREF)
+        .def_readonly("spheres",   &Simul::spheres , PYREF)
+        .def_readonly("beads",   &Simul::beads , PYREF)
+        .def_readonly("solids",   &Simul::solids , PYREF)
+        .def_readonly("couples",   &Simul::couples , PYREF)
+        .def_readonly("singles",   &Simul::singles , PYREF)
+        .def_readonly("organizers",   &Simul::organizers , PYREF)
         .def("remove",  [](Simul * sim, Object* obj) {return sim->remove(obj);})
         .def("erase",  [](Simul * sim, Object* obj) {return sim->erase(obj);})
         .def("nuke",  [](Simul * sim) {return sim->erase();})
@@ -114,13 +114,13 @@ auto load_simul_classes(py::module_ &m) {
         .def("solve_auto",  [](Simul * sim) {return sim->solve_auto();})
         //.def("dump",  [](Simul * sim, std::string s) {return sim->dump( &s[0]);})
         //.def("saveSystem",  [](Simul * sim, char s) {return sim->saveSystem((char) s);})
-        .def("evaluate",  [](Simul * sim, std::string s) {return sim->evaluate(s);} , py::return_value_policy::reference)
-        .def("toMecable",  [](Simul * sim, Object* o) {return sim->toMecable(o);} , py::return_value_policy::reference)
-        .def("findMecable",  [](Simul * sim, std::string s) {return sim->findMecable(s);} , py::return_value_policy::reference)
-        .def("findSpace",  [](Simul * sim, std::string s) {return sim->findSpace(s);} , py::return_value_policy::reference)
-        .def("rename",  [](Simul * sim, std::string s) {return sim->rename(s);} , py::return_value_policy::reference)
-        .def("isCategory",  [](Simul * sim, std::string s) {return sim->isCategory(s);} , py::return_value_policy::reference)
-        .def("findProperty",  [](Simul * sim, std::string s) {return sim->findProperty(s);} , py::return_value_policy::reference)
+        .def("evaluate",  [](Simul * sim, std::string s) {return sim->evaluate(s);} , PYREF)
+        .def("toMecable",  [](Simul * sim, Object* o) {return sim->toMecable(o);} , PYREF)
+        .def("findMecable",  [](Simul * sim, std::string s) {return sim->findMecable(s);} , PYREF)
+        .def("findSpace",  [](Simul * sim, std::string s) {return sim->findSpace(s);} , PYREF)
+        .def("rename",  [](Simul * sim, std::string s) {return sim->rename(s);} , PYREF)
+        .def("isCategory",  [](Simul * sim, std::string s) {return sim->isCategory(s);} , PYREF)
+        .def("findProperty",  [](Simul * sim, std::string s) {return sim->findProperty(s);} , PYREF)
         .def("writePropertiesTo",  [](Simul * sim, std::string s) {return sim->writeProperties(&s[0],1);} )
         .def("writeProperties",  [](Simul * sim, bool prune) {return sim->writeProperties(&sim->prop->property_file[0], prune);} )
         .def("writePropertiesToNoPrune",  [](Simul * sim, std::string  s) {return sim->writeProperties(&s[0],0);} );
@@ -137,8 +137,8 @@ auto load_simul_classes(py::module_ &m) {
         .def_readwrite("acceptable_prop", &SimulProp::acceptable_prob)
         .def_readwrite("precondition", &SimulProp::precondition)
         .def_readwrite("steric", &SimulProp::steric)
-        .def("steric_stiffness_push",  [](SimulProp * prop) {return to_numpy_raw(prop->steric_stiffness_push, 1, 2); })
-        .def("steric_stiffness_pull",  [](SimulProp * prop) {return to_numpy_raw(prop->steric_stiffness_pull, 1, 2); })
+        .def("steric_stiffness_push",  [](SimulProp * prop) {return to_numpy_raw(prop->steric_stiffness_push, 1, 2); }, PYOWN)
+        .def("steric_stiffness_pull",  [](SimulProp * prop) {return to_numpy_raw(prop->steric_stiffness_pull, 1, 2); }, PYOWN)
         .def_readwrite("steric_max_range", &SimulProp::steric_max_range)
         .def_readwrite("binding_grid_step", &SimulProp::binding_grid_step)
         .def_readwrite("verbose", &SimulProp::verbose)
@@ -150,7 +150,8 @@ auto load_simul_classes(py::module_ &m) {
         .def_readwrite("display_fresh", &SimulProp::display_fresh)
         .def_readwrite("display", &SimulProp::display)
         .def("read",  [](SimulProp * prop, Glossary & glos) {return prop->read(glos);})
-        .def("read_str",  [](SimulProp * prop, std::string const& str) {return prop->read(str_to_glos(str));})
+        .def("read_str",  [](SimulProp * prop, std::string const& str) 
+                {Glossary * glos = str_to_glos(str) ; return prop->read(*glos);})
         .def("clone",  [](SimulProp * prop) {return prop->clone();});
         
 
