@@ -12,12 +12,12 @@ class Object;
 void load_solid_classes(py::module_ &m) {
     /// Python interface to Solid
     py::class_<Mecable,Object>(m, "Mecable")
-        .def("data",   [](Mecable * mec) {return get_obj_data(mec);})
+        .def("data",   [](Mecable * mec) {return get_obj_data(mec);}, PYOWN)
         .def("nbPoints", &Mecable::nbPoints)
         .def("allocated", &Mecable::allocated)
-        .def("points",  [](Mecable * mec) {return get_obj_points(mec);},
+        .def("points",  [](Mecable * mec) {return get_obj_points(mec);}, PYOWN,
                 "@PYD;T: Returns read-only point coordinates of the mecable")
-        .def("posPoint",  [](Mecable * mec,int p) {return to_numpy(mec->posPoint(p));})
+        .def("posPoint",  [](Mecable * mec,int p) {return to_numpy(mec->posPoint(p));}, PYOWN)
         .def("setPoint",  [](Mecable * mec, int i, pyarray vec) 
             {   Vector p = to_vector(vec);
                 return mec->setPoint(i,p);})
@@ -36,7 +36,7 @@ void load_solid_classes(py::module_ &m) {
             {Vector V,W; 
             mec->calculateMomentum(V,W,sub);
                 return std::vector<pyarray>{to_numpy(V),to_numpy(W)};
-                })
+                }, PYOWN)
         .def("netForce",  [](Mecable * mec,int p) {return to_numpy(mec->netForce(p));})
         .def("position",  [](Mecable * mec) {return to_numpy(mec->position());})
         .def("translate",  [](Mecable * mec, pyarray vec) 
@@ -45,8 +45,8 @@ void load_solid_classes(py::module_ &m) {
         .def("allInside", &Mecable::allInside);
         
     py::class_<Sphere,Mecable>(m, "Sphere")
-        .def("position",  [](Sphere * bed) {return to_numpy(bed->position());})
-        .def("pos",  [](Sphere * bed) {return to_numpy(bed->position());})
+        .def("position",  [](Sphere * bed) {return to_numpy(bed->position());}, PYOWN)
+        .def("pos",  [](Sphere * bed) {return to_numpy(bed->position());}, PYOWN)
         .def("radius", &Sphere::radius)
         .def("resize", &Sphere::resize)
         .def("reshape", &Sphere::reshape)
@@ -54,42 +54,42 @@ void load_solid_classes(py::module_ &m) {
         .def("addSurfacePoint", [](Sphere & bed, pyarray pos) {bed.addSurfacePoint(to_vector(pos));})
         .def("nbbSurfacePoints", &Sphere::nbSurfacePoints)
         .def("dragCoefficient", &Sphere::dragCoefficient)
-        .def("next", &Sphere::next, py::return_value_policy::reference)
-        .def("prev", &Sphere::prev, py::return_value_policy::reference)
-        .def("toSphere",  [](Object * obj) {return Sphere::toSphere(obj);},  py::return_value_policy::reference);
+        .def("next", &Sphere::next, PYREF)
+        .def("prev", &Sphere::prev, PYREF)
+        .def("toSphere",  [](Object * obj) {return Sphere::toSphere(obj);},  PYREF);
         
     
     py::class_<Bead,Mecable>(m, "Bead")
-        .def("position",  [](Bead * bed) {return to_numpy(bed->position());})
-        .def("pos",  [](Bead * bed) {return to_numpy(bed->position());})
+        .def("position",  [](Bead * bed) {return to_numpy(bed->position());}, PYOWN)
+        .def("pos",  [](Bead * bed) {return to_numpy(bed->position());}, PYOWN)
         .def("setPosition",  [](Bead * bed, pyarray pos) {bed->setPosition(to_vector(pos));})
         .def("radius", &Bead::radius)
         .def("radiusSqr", &Bead::radiusSqr)
         .def("resize", &Bead::resize)
         .def("volume", &Bead::volume)
         .def("dragCoefficient", &Bead::dragCoefficient)
-        .def("next", &Bead::next, py::return_value_policy::reference)
-        .def("prev", &Bead::prev, py::return_value_policy::reference)
-        .def("toBead",  [](Object * obj) {return Bead::toBead(obj);},  py::return_value_policy::reference);
+        .def("next", &Bead::next, PYREF)
+        .def("prev", &Bead::prev, PYREF)
+        .def("toBead",  [](Object * obj) {return Bead::toBead(obj);},  PYREF);
         
         
         
         
     
     py::class_<Solid,Object>(m, "Solid")
-        .def("position", [](const Solid * sol) {return to_numpy(sol->position());})
-        .def("points",  [](Solid * sol) {return get_obj_points(sol);})
+        .def("position", [](const Solid * sol) {return to_numpy(sol->position());}, PYOWN)
+        .def("points",  [](Solid * sol) {return get_obj_points(sol);}, PYOWN)
         .def("dragCoefficient",  [](Solid * sol) {return sol->dragCoefficient() ;})
         .def("addSphere",  [](Solid * sol, pyarray pts, real radius) {return sol->addSphere(to_vector(pts), radius) ;})
         .def("setRadius",  [](Solid * sol, int i, real radius) {return sol->radius((unsigned) i, radius) ;})
         .def("radius",  [](Solid * sol, int i) {return sol->radius((unsigned) i) ;})
-        .def("centroid", [](const Solid * sol) {return to_numpy(sol->centroid());})
+        .def("centroid", [](const Solid * sol) {return to_numpy(sol->centroid());}, PYOWN)
         .def("next",  [](Solid * sol) {return sol->next() ;})
         .def("prev",  [](Solid * sol) {return sol->prev() ;})
         .def("tag",  [](Solid * sol) {return sol->tag() ;})
         .def("property",  [](Solid * sol) {return sol->property() ;})
         .def("nbPoints", [](const Solid * sol) {return sol->nbPoints();})
-        .def("toSolid",  [](Object * obj) {return Solid::toSolid(obj);},  py::return_value_policy::reference);
+        .def("toSolid",  [](Object * obj) {return Solid::toSolid(obj);},  PYREF);
          
          /**
             @TODO : ADD SPECIALIZED SOLID CLASSES
