@@ -69,7 +69,7 @@ void EventSet::write(Outputter& out) const
 {
     if ( size() > 0 )
     {
-        out.put_line("\n#section "+title(), out.binary());
+        out.write("\n#section "+title());
         writeNodes(out, nodes);
     }
 }
