@@ -183,7 +183,10 @@ void Fiber::cutM(real len)
     {
         Hand * nx = ha->next();
         if ( ha->abscissa() < abs )
+        {
+            ha->reinterpolate();
             ha->detach();
+        }
         ha = nx;
     }
 }
@@ -204,7 +207,10 @@ void Fiber::cutP(real len)
     {
         Hand * nx = ha->next();
         if ( ha->abscissa() > abs )
+        {
+            ha->reinterpolate();
             ha->detach();
+        }
         ha = nx;
     }
 }
@@ -251,15 +257,14 @@ Fiber* Fiber::severPoint(unsigned int pti)
     {
         Hand * nx = ha->next();
         if ( ha->abscissa() > abs )
-            ha->relocate(fib);
+            ha->relocate(fib, ha->abscissa());
         else
             ha->reinterpolate();
         ha = nx;
     }
     
-    resetLattice();
-    fib->resetLattice();
-    
+    if ( resetLattice(1) )
+        fib->resetLattice(0);
     return fib;
 }
 
@@ -313,15 +318,14 @@ Fiber* Fiber::severM(real abs)
     {
         Hand * nx = ha->next();
         if ( ha->abscissa() >= abs )
-            ha->relocate(fib);
+            ha->relocate(fib, ha->abscissa());
         else
             ha->reinterpolate();
         ha = nx;
     }
 
-    resetLattice();
-    fib->resetLattice();
-
+    if ( resetLattice(1) )
+        fib->resetLattice(0);
     return fib;
 }
 
@@ -376,6 +380,7 @@ void Fiber::severNow()
 
             //add new fragment to simulation:
             objset()->add(frag);
+            //std::clog << "sever " << reference() << " at " << abscissaP() << " --> " << frag->reference() << "\n";
 
             if ( frag )
             {
@@ -493,7 +498,7 @@ void Fiber::join(Fiber * fib)
     }
     delete(fib);
 
-    resetLattice();
+    resetLattice(1);
 }
 
 
@@ -772,8 +777,8 @@ void Fiber::setInteractions(Meca & meca) const
         for ( unsigned i = 0; i < nbSegments(); ++i )
         {
             Vector f = s * dirSegment(i);
-            meca.addForce(Mecapoint(this, i  ), f);
-            meca.addForce(Mecapoint(this, i+1), f);
+            meca.addForce(this, i  , f);
+            meca.addForce(this, i+1, f);
         }
     }
 #endif
