@@ -96,11 +96,8 @@ public:
     /// set previous Hand in Fiber's list
     void    prev(Hand * h) { haPrev = h; }
 
-    
-    /// move to a different fiber, at the same abscissa
-    void           relocate(Fiber* f);
-    
-    /// move to a different fiber, at the given abscissa
+
+    /// move to same or different fiber, at the given abscissa
     void           relocate(Fiber* f, real a);
 
     /// relocate to the specified tip of the current fiber
