@@ -126,20 +126,6 @@ void Interface::execute_change_all(std::string const& cat, Glossary& def)
 //------------------------------------------------------------------------------
 #pragma mark -
 
-/// check if stream still contains a non-space character
-bool has_trail(std::istream& is)
-{
-    int c = is.get();
-    while ( isspace(c) )
-        c = is.get();
-    if ( c != EOF )
-    {
-        is.unget();
-        return true;
-    }
-    return false;
-}
-
 /// report warning
 void warn_trail(std::istream& is, std::string const& msg)
 {
@@ -168,7 +154,7 @@ Isometry Interface::read_placement(Glossary& opt)
     {
         std::istringstream iss(str);
         iso.mov = Movable::readPosition(iss, spc);
-        if ( has_trail(iss) ) warn_trail(iss, "position = "+str);
+        if ( StreamFunc::has_trail(iss) ) warn_trail(iss, "position = "+str);
     }
     else if ( spc )
     {
@@ -180,13 +166,13 @@ Isometry Interface::read_placement(Glossary& opt)
     {
         std::istringstream iss(str);
         iso.rot = Movable::readOrientation(iss, iso.mov, spc);
-        if ( has_trail(iss) ) warn_trail(iss, "orientation = "+str);
+        if ( StreamFunc::has_trail(iss) ) warn_trail(iss, "orientation = "+str);
     }
     else if ( opt.set(str, "direction") )
     {
         std::istringstream iss(str);
         Vector vec = Movable::readDirection(iss, iso.mov, spc);
-        if ( has_trail(iss) ) warn_trail(iss, "direction = "+str);
+        if ( StreamFunc::has_trail(iss) ) warn_trail(iss, "direction = "+str);
         iso.rot = Rotation::randomRotationToVector(vec);
     }
     else
@@ -197,7 +183,7 @@ Isometry Interface::read_placement(Glossary& opt)
     {
         std::istringstream iss(str);
         Rotation rot = Movable::readOrientation(iss, iso.mov, spc);
-        if ( has_trail(iss) ) warn_trail(iss, "orientation = "+str);
+        if ( StreamFunc::has_trail(iss) ) warn_trail(iss, "orientation = "+str);
         iso.rotate(rot);
     }
     
@@ -240,164 +226,266 @@ enum PlacementType { PLACE_NOT, PLACE_ANYWHERE, PLACE_INSIDE, PLACE_EDGE,
  inside the Space, and the density will thus be exactly what is specified from the
  `position` range (here 100/10*10 = 1 object per squared micrometer).
  */
-Isometry Interface::find_placement(Glossary& opt, int placement)
+bool Interface::find_placement(Isometry& iso, Glossary& opt, int placement)
 {
-    int n = 0, nb_trials = 1<<13;
     std::string str;
-    
-    opt.set(nb_trials, "nb_trials");
-
     Space const* spc = simul.spaces.master();
     if ( opt.set(str, "placement", 1) )
         spc = simul.findSpace(str);
-    
-    // define a condition:
-    bool has_condition = false;
-    std::string condition_str;
-    if ( opt.set(condition_str, "placement", 2) )
-        has_condition = true;
-    
-    Isometry iso;
 
-    while ( ++n < nb_trials )
+    // generate a new position:
+    iso = read_placement(opt);
+    
+    if ( iso.invalid() )
+        return 0;
+    
+    // check any conditions to the position:
+    bool has_condition = opt.set(str, "placement", 2);
+    if ( has_condition )
     {
-        // generate a new position:
-        iso = read_placement(opt);
-
-        // check all conditions:
-        bool condition = true;
-        if ( has_condition )
-        {
-            Evaluator evaluator{{'X', iso.mov.x()}, {'Y', iso.mov.y()}, {'Z', iso.mov.z()},
-                                {'R', iso.mov.norm()}, {'P', RNG.preal()}};
-            try {
-                char const* ptr = condition_str.c_str();
-                condition = evaluator.evaluate(ptr);
-            }
-            catch( Exception& e ) {
-                e.message(e.message()+" in `"+condition_str+"'");
-                throw;
-            }
+        Evaluator evaluator{{'X', iso.mov.x()}, {'Y', iso.mov.y()}, {'Z', iso.mov.z()},
+            {'R', iso.mov.norm()}, {'P', RNG.preal()}};
+        try {
+            if ( 0 == evaluator.evaluate(str.c_str()) )
+                return 0;
         }
-        
-        if ( condition )
-        {
-            if ( !spc || placement == PLACE_ANYWHERE )
-                return iso;
-            
-            if ( placement == PLACE_EDGE )
-            {
-                iso.mov = spc->project(iso.mov);
-                return iso;
-            }
-            
-            if ( spc->inside(iso.mov) )
-            {
-                if ( placement == PLACE_INSIDE || placement == PLACE_ALL_INSIDE )
-                    return iso;
-            }
-            else
-            {
-                if ( placement == PLACE_OUTSIDE )
-                    return iso;
-            }
+        catch( Exception& e ) {
+            e.message(e.message()+" in `"+str+"'");
+            throw;
         }
     }
     
-    //Cytosim::warn << "could not fulfill `position=" + opt.value("position", 0) + "'\n";
-    throw InvalidParameter("could not fulfill `position=" + opt.value("position", 0) + "'");
-    //iso.reset(); return iso;
+    if ( !spc || placement == PLACE_ANYWHERE )
+        return 1;
+    
+    if ( placement == PLACE_EDGE )
+    {
+        iso.mov = spc->project(iso.mov);
+        return 1;
+    }
+    
+    if ( spc->inside(iso.mov) )
+    {
+        if ( placement == PLACE_INSIDE || placement == PLACE_ALL_INSIDE )
+            return 1;
+    }
+    else
+    {
+        if ( placement == PLACE_OUTSIDE )
+            return 1;
+    }
+    
+    return 0;
+}
+
+
+
+bool all_points_inside(ObjectList const& objs, Space const* spc)
+{
+    for ( Object * i : objs )
+    {
+        Mecable * mec = Simul::toMecable(i);
+        if ( mec && ! mec->allInside(spc) )
+            return false;
+    }
+    return true;
+}
+
+/**
+ This would usually create ONE object of type 'pp', placed according to `opt`
+ */
+ObjectList Interface::new_object(ObjectSet* set, Property const* pp, Glossary& opt)
+{
+    ObjectList objs;
+    long max_trials = 1024;
+    opt.set(max_trials, "nb_trials");
+    long nb_trials = max_trials;
+    Glossary::dict_type<PlacementType> keys{
+        {"off",        PLACE_NOT},
+        {"none",       PLACE_NOT},
+        {"anywhere",   PLACE_ANYWHERE},
+        {"inside",     PLACE_INSIDE},
+        {"all_inside", PLACE_ALL_INSIDE},
+        {"outside",    PLACE_OUTSIDE},
+        {"surface",    PLACE_EDGE}};
+    
+    while ( --nb_trials >= 0 )
+    {
+        objs = set->newObjects(pp->name(), opt);
+        
+        // early bailout for immobile objects:
+        if ( objs.size()==1 && !objs[0]->mobile() )
+            break;
+        
+        PlacementType placement = PLACE_INSIDE;
+        opt.set(placement, "placement", keys);
+        if ( placement == PLACE_NOT )
+            break;
+        
+        // find possible position & rotation:
+        Isometry iso;
+        if ( find_placement(iso, opt, placement) )
+        {
+            // place object at this position:
+            for ( Object * obj : objs )
+                obj->move(iso);
+            // special case for which we check all vertices:
+            bool okay = true;
+            if ( placement == PLACE_ALL_INSIDE )
+            {
+                std::string str;
+                Space const* spc = simul.spaces.master();
+                if ( opt.set(str, "placement", 1) )
+                    spc = simul.findSpace(str);
+                okay = all_points_inside(objs, spc);
+            }
+            if ( okay )
+                break;
+        }
+        else
+        {
+            // no suitable placement found, delete new objects:
+            for ( Object* i : objs )
+                if ( ! i->linked() )
+                    delete(i);
+            objs.clear();
+            continue;
+        }
+        /*
+         objects that were just created by newObjects() are not yet linked and
+         will be deleted. Older objects will be moved back to their original position
+         */
+        iso.inverse();
+        for ( Object* i : objs )
+        {
+            if ( ! i->linked() )
+                delete(i);
+            else
+                i->move(iso);
+        }
+        objs.clear();
+    }
+    
+    if ( objs.empty() )
+    {
+        std::string name = pp ? pp->name() : "object";
+        if ( max_trials > 1 )
+            Cytosim::log << "could not place `" << name << "' after " << max_trials << " trials\n";
+        return objs;
+    }
+
+    // optionally mark the objects:
+    ObjectMark mk = 0;
+    if ( opt.value_is("mark", 0, "random") )
+        mk = RNG.pint32();
+    if ( mk || opt.set(mk, "mark") )
+    {
+        for ( Object * i : objs )
+            i->mark(mk);
+    }
+
+    // translation after placement
+    Vector vec;
+    if ( opt.set(vec, "translation") )
+        ObjectSet::translateObjects(objs, vec);
+    
+    //std::clog << "new_object " << objs.size() << " " << pp->name() << "\n";
+    return objs;
 }
 
 
 /**
- This would usually create ONE object of type 'name'.
+ Create `cnt` objects of type 'name', according to specifications.
+ It is possible to make an object without an associated Property
  */
-ObjectList Interface::execute_new(std::string const& name, Glossary& opt)
+ObjectList Interface::execute_new(std::string const& cat, std::string const& name, Glossary& opt, size_t cnt)
 {
     ObjectList res;
     ObjectSet * set = nullptr;
+    Property const* pp = simul.properties.find(name);
+    
+    if ( cat.empty() && pp )
     {
-        Property * pp = simul.properties.find(name);
-        // Allows to make an object without an associated Property
-        if ( pp )
-            set = simul.findSet(pp->category());
-        else
-            set = simul.findSet(name);
+        set = simul.findSet(pp->category());
+        if ( !set )
+            throw InvalidSyntax("could not determine the class of `"+name+"'");
     }
-    if ( !set )
+    else if ( cat.empty() )
         throw InvalidSyntax("could not determine the class of `"+name+"'");
-    
-    do {
-        
-        // create the objects:
-        res = set->newObjects(name, opt);
-        
-#if ( 0 )
-        // check for zero value in list, which should not happen:
-        if ( res.count(nullptr) )
-        {
-            std::clog << "cytosim found empty slots in newObjects(" << name << ")\n";
-            res.remove_pack(nullptr);
-        }
-#endif
-        
-        PlacementType placement = PLACE_INSIDE;
-        
-        opt.set(placement, "placement",{{"off",       PLACE_NOT},
-#ifdef BACKWARD_COMPATIBILITY
-                                       {"none",       PLACE_NOT},
-#endif
-                                       {"anywhere",   PLACE_ANYWHERE},
-                                       {"inside",     PLACE_INSIDE},
-                                       {"all_inside", PLACE_ALL_INSIDE},
-                                       {"outside",    PLACE_OUTSIDE},
-                                       {"surface",    PLACE_EDGE}});
-        
-        if ( placement != PLACE_NOT )
-        {
-            Isometry iso = find_placement(opt, placement);
-            ObjectSet::moveObjects(res, iso);
-            // special case for which we check all vertices:
-            if ( placement == PLACE_ALL_INSIDE )
-            {
-                for ( Object * i : res )
-                {
-                    Mecable * mec = Simul::toMecable(i);
-                    if ( mec && ! mec->allInside(simul.spaces.master()) )
-                    {
-                        res.destroy();
-                        continue;
-                    }
-                }
-            }
-        }
-        
-    } while ( res.empty() );
-    
-    // optionally mark the objects:
-    ObjectMark mk = 0;
-    if ( opt.set(mk, "mark") )
+    else
     {
-        for ( Object * i : res )
-            i->mark(mk);
+        set = simul.findSet(cat);
+        if ( !set )
+            throw InvalidSyntax("undefined class `"+cat+"'");
     }
     
-    // syntax sugar, translation after placement
-    Vector vec;
-    if ( opt.set(vec, "translation") )
-        ObjectSet::translateObjects(res, vec);
+    size_t amount = set->size();
 
-    /* 
+    // syntax sugar: distribute objects regularly between two points
+    if ( opt.has_key("range") )
+    {
+        Vector A, B;
+        if ( !opt.set(A, "range") || !opt.set(B, "range", 1) )
+            throw InvalidParameter("two vectors need to be defined by `range'");
+        if ( opt.has_key("position") )
+            throw InvalidParameter("cannot specify `position' if `range' is defined");
+        Vector dAB = ( B - A ) / std::max(1UL, cnt-1);
+        
+        for ( size_t n = 0; n < cnt; ++n )
+        {
+            opt.define("position", A + n * dAB);
+            res.append(new_object(set, pp, opt));
+        }
+    }
+    // syntax sugar: positions specified for multiple objects
+    else if ( opt.nb_values("positions") > 0 )
+    {
+        for ( size_t n = 0; n < cnt; ++n )
+        {
+            size_t i = opt.least_used_index(opt.values("positions"));
+            opt.define("position", opt.value("positions", i));
+            res.append(new_object(set, pp, opt));
+        }
+    }
+    else
+    {
+        // syntax sugar: specify the positions of the Fiber's ends
+        if ( opt.has_key("position_ends") )
+        {
+            Vector A, B;
+            if ( !opt.set(A, "position_ends") || !opt.set(B, "position_ends", 1) )
+                throw InvalidParameter("two vectors need to be defined by `position_ends'");
+            opt.define("length",    (A-B).norm());
+            opt.define("position",  (A+B)*0.5);
+            opt.define("direction", (B-A).normalized());
+        }
+        
+        // normal pathway:
+        for ( size_t n = 0; n < cnt; ++n )
+            res.append(new_object(set, pp, opt));
+    }
+    //hold();
+    
+    /*
      Because the objects in ObjectList are not necessarily all of the same class,
-     we call simul.add() rather than directly set->add()
+     for example a Single can be created along with a Fiber in FiberSet::newObjects,
+     we call here sim_->add() rather than directly set->add()
      */
     simul.add(res);
-    
-    //hold();
 
-    VLOG("+NEW `" << name << "' made " << res.size() << " objects\n");
-    
+    size_t required = 0;
+    if ( opt.set(required, "required") )
+    {
+        size_t created = set->size() - amount;
+        if ( created < required )
+        {
+            std::cerr << "created  = " << created << '\n';
+            std::cerr << "required = " << required << '\n';
+            throw InvalidParameter("could not create enough `"+name+"'");
+        }
+    }
+
+    VLOG("+NEW " << cat << " `" << name << "' made " << set->size()-amount << " objects (total " << sim_->nbObjects() << ")");
     return res;
 }
 
@@ -405,60 +493,82 @@ ObjectList Interface::execute_new(std::string const& name, Glossary& opt)
 //------------------------------------------------------------------------------
 /**
  Creates `cnt` objects of class `name`.
- The objects are placed at random position in a random orientation within the current Space.
+ The objects are distributed at the specified position in the given Space,
+ with random orientations.
  
- This is meant to be faster than calling execute_new(name, opt) `cnt` times.
+ This is meant to replace execute_new(cat, name, opt, cnt), when no fancy
+ option were specified to the command.
  */
-void Interface::execute_new(std::string const& name, unsigned cnt)
+ObjectList Interface::execute_new(std::string const& name, size_t cnt,
+                                  Space const* spc, std::string const& position)
 {
-    Property * pp = simul.properties.find_or_die(name);
+    Property const* pp = simul.properties.find_or_die(name);
     ObjectSet * set = simul.findSet(pp->category());
     if ( !set )
         throw InvalidSyntax("could not determine the class of `"+name+"'");
 
-    Space const* spc = simul.spaces.master();
-
     Glossary opt;
+    ObjectList res;
 
-    for ( unsigned n = 0; n < cnt; ++n )
+    for ( size_t n = 0; n < cnt; ++n )
     {
-        ObjectList objs = set->newObjects(name, opt);
+        ObjectList objs = set->newObjects(pp->name(), opt);
         
         if ( objs.empty() )
-            throw InvalidSyntax("could not create object class of `"+name+"'");
+            throw InvalidSyntax("could not create any `"+name+"'");
+        
+        Object * obj = nullptr;
+        if ( objs.size() == 1 )
+            obj = objs[0];
 
         if ( spc )
         {
-            // This is a very common case, where we can skip Rotation::randomRotation():
-            if ( objs.size() == 1 )
+            Vector pos;
+            if ( position.empty() )
+                pos = spc->randomPlace();
+            else
+                pos = Movable::readPosition(position, spc);
+            
+            if ( !pos.valid() )
             {
-                Object * obj = objs[0];
+                objs.destroy();
+                continue;
+            }
+            
+            if ( obj )
+            {
+                // here the random rotation is only generated if needed:
                 switch ( obj->mobile() )
                 {
                     case 2: obj->rotate(Rotation::randomRotation()); break;
                     case 3: obj->rotate(Rotation::randomRotation());
-                    case 1: obj->translate(spc->randomPlace());
+                    case 1: obj->translate(pos);
                 }
             }
             else
             {
-                Isometry iso(spc->randomPlace(), Rotation::randomRotation());
-                ObjectSet::moveObjects(objs, iso);
+                Isometry iso(Rotation::randomRotation(), pos);
+                for ( Object * o : objs )
+                    o->move(iso);
             }
         }
         
-        /* 
-         Because the objects in ObjectList are not necessarily all of the same class,
-         we call simul.add() rather than directly set->add()
-         */
-        simul.add(objs);
+        /* Call sim_->add(), in case the list might contain heterogenous objects */
+        if ( obj ) {
+            set->add(obj);
+            res.push_back(obj);
+        } else {
+            simul.add(objs);
+            res.append(objs);
+        }
     }
     
-    VLOG("-NEW " << cnt << "`" << name << "' objects\n");
-
+    VLOG("-NEW " << cnt << " `" << name << "' at `" << position << "'");
     //hold();
+    return res;
 }
 
+
 //------------------------------------------------------------------------------
 #pragma mark -
 
