@@ -323,7 +323,10 @@ public:
 
     /// Add a constant force on Mecapoint
     void addForce(Mecapoint const&, Vector const& force);
-    
+ 
+    /// Add a constant force on point `inx` of  Mecapoint
+    void addForce(Mecable const*, index_t inx, Vector const& force);
+
     /// Add a constant force on Interpolated point
     void addForce(Interpolation const&, Vector const& force);
     
