@@ -14,49 +14,6 @@
 #include "simul.h"
 
 
-/** The default implementation is invalid */
-void Movable::translate(Vector const&)
-{
-    ABORT_NOW("Movable::translate() called for immobile Object");
-}
-
-/** The default implementation is invalid */
-void Movable::rotate(Rotation const& rot)
-{
-    ABORT_NOW("Movable::rotate() called for immobile Object");
-}
-
-/*
- if possible, the Object is translated by `[ rot * Object::position() - Object::position() ]`
- 
- Note that this has no effect if the Object is at the origin
-*/
-void Movable::rotateT(Rotation const& rot)
-{
-    assert_true( mobile() == 1 );
-    Vector pos = position();
-    translate(rot*pos-pos);
-}
-
-/**
-revolve() implements:
-
-    Vector G = position();
-    translate( -G );
-    rotate( T );
-    translate(  G );
-*/
-void Movable::revolve(Rotation const& T)
-{
-    Vector G = position();
-    translate( -G );
-    rotate( T );
-    translate(  G );
-}
-
-//------------------------------------------------------------------------------
-#pragma mark -
-
 /**
  There are different ways to specify a position:
  
@@ -935,3 +892,19 @@ Rotation Movable::readOrientation(std::istream& is, Vector const& pos, Space con
     return Rotation::randomRotationToVector(vec);
 }
 
+
+
+
+/// convert string to a position
+Vector Movable::readPosition(std::string const& arg, Space const* spc)
+{
+    std::istringstream iss(arg);
+    Vector vec = Movable::readPosition(iss, spc);
+    if ( StreamFunc::has_trail(iss) )
+    {
+        std::string str;
+        std::getline(iss, str);
+        throw InvalidSyntax("unexpected trailing `"+str+"' in position `"+arg+"'");
+    }
+    return vec;
+}
