@@ -428,7 +428,7 @@ inline bool adjacent(FatPoint const* a, FatPoint const* b)
 }
 
 
-/// excluding Fiber and Solid from the same Aster
+/// excluding Fiber and Solid from the same Aster, or from a nucleus
 inline bool adjacent(FatPoint const* a, FatSegment const* b)
 {
     //a->pnt.mecable()->Buddy::print(std::clog);
@@ -441,7 +441,7 @@ inline bool adjacent(FatPoint const* a, FatSegment const* b)
 inline bool adjacent(FatSegment const* a, FatSegment const* b)
 {
     return (( a->seg.fiber() == b->seg.fiber() )
-            & ( a->seg.point() < 2 + b->seg.point() ) & ( b->seg.point() < 2 + a->seg.point() ));
+            && ( a->seg.point() < 2 + b->seg.point() ) && ( b->seg.point() < 2 + a->seg.point() ));
 }
 
 //------------------------------------------------------------------------------
