@@ -32,17 +32,6 @@ const char TRAJECTORY[] = "objects.cmo";
 
 
 /// Simulator class containing all Objects
-/**
-
- Simul is the core class of cytosim. 
- It holds the various sets of objects in the simulation, and methods to alter 
- these objects, and progress the simulation.
- It holds for example : 
- - `Fibers` (a FiberSet)
- - `Spaces` (a SpaceSet)
- - `Singles` (a SingleSet)
- - Etc. 
- */
 class Simul
 {
 public:
@@ -224,7 +213,7 @@ private:
     void            setFiberGrid(Space const*) const;
     
     /// give an estimate for the cell size of the PointGrid used for steric interactions
-    real            estimateStericRange() const;
+    real            minimumStericRange() const;
     
     /// initialize the grid for steric interaction (pointGrid)
     void            setStericGrid(Space const*) const;
@@ -482,7 +471,7 @@ public:
     void      reportSinglePosition(std::ostream&, std::string const&) const;
    
     /// print position of Singles
-    void      reportAttachedSingle(std::ostream&, std::string const&) const;
+    void      reportSingleLink(std::ostream&, std::string const&) const;
 
     /// print state of Couples 
     void      reportSpherePosition(std::ostream&) const;
