@@ -279,11 +279,13 @@ void Simul::report0(std::ostream& out, std::string const& arg, Glossary& opt) co
             return reportSingle(out);
         if ( what == "state" || what == "force" )
             return reportSingleState(out, which);
+        if ( what == "link" )
+            return reportSingleLink(out, which);
         if ( what == "position" )
             return reportSinglePosition(out, which);
         if ( what == "attached" )
-            return reportAttachedSingle(out, which);
-        throw InvalidSyntax("I only know single: state, force, position, NAME");
+            return reportSingleLink(out, which);
+        throw InvalidSyntax("I only know single: state, link, force, position, NAME");
     }
     if ( who == "couple" )
     {
@@ -1141,7 +1143,7 @@ void Simul::reportFiberIntersections(std::ostream& out, Glossary& opt) const
                     FiberSegment seg2(fob, jj);
                     if ( seg1.shortestDistance(seg2, abs1, abs2) < sup )
                     {
-                        if ( seg1.within(abs1) & seg2.within(abs2) )
+                        if ( seg1.within(abs1) && seg2.within(abs2) )
                         {
                             ++cnt;
                             Vector pos1 = seg1.pos(abs1/seg1.len());
@@ -1522,7 +1524,7 @@ void Simul::reportSinglePosition(std::ostream& out, std::string const& which) co
 /**
  Export details of attached Singles
  */
-void Simul::reportAttachedSingle(std::ostream& out, std::string const& which) const
+void Simul::reportSingleLink(std::ostream& out, std::string const& which) const
 {
     Property * selected = nullptr;
     
