@@ -1,4 +1,6 @@
 // Cytosim was created by Francois Nedelec. Copyright 2007-2017 EMBL.
+
+#include "messages.h"
 #include "assert_macro.h"
 #include "random_vector.h"
 #include "solid.h"
@@ -909,10 +911,10 @@ void Solid::setDragCoefficient()
     
     // sanity check:
     if ( soDrag < REAL_EPSILON )
-        throw InvalidParameter("The Solid's drag coefficient is null");
+        throw InvalidParameter("solid "+reference()+" has no drag (no bead with radius > 0)");
 
     if ( soDragRot < REAL_EPSILON )
-        throw InvalidParameter("ill-formed Solid has zero rotational drag");
+        throw InvalidParameter("ill-formed Solid "+reference()+" has zero rotational drag");
 
 #if ( 0 )
     std::clog << "Solid " << reference() << " (viscosity " << prop->viscosity << ") has drag:\n";
@@ -1173,7 +1175,7 @@ void Solid::write(Outputter& out) const
     for ( unsigned p = 0; p < nPoints ; ++p )
     {
         out.writeFloats(pPos + DIM * p, DIM, '\n');
-        out.writeSoftSpace(2);
+        out.writeSoftSpace();
         out.writeFloat(soRadius[p]);
     }
 }
