@@ -12,7 +12,6 @@
 #include "space_prop.h"
 #include "space.h"
 #include "sphere.h"
-#include "wrist.h"
 #include "meca.h"
 #include "modulo.h"
 #include "simul.h"
@@ -265,14 +264,13 @@ void Sphere::resize(const real R)
 void Sphere::setDragCoefficientStokes()
 {
     assert_true( spRadius > 0 );
-    
     const real rad = spRadius;
     
-    //hydrodynamic not corrected: infinite fluid is assumed
-    spDrag    = 6 * M_PI * prop->viscosity * rad;
-    spDragRot = 8 * M_PI * prop->viscosity * rad * rad * rad;
+    // hydrodynamic not corrected: infinite fluid is assumed
+    spDrag    = ( 6 * M_PI ) * ( prop->viscosity * rad );
+    spDragRot = ( 8 * M_PI ) * ( prop->viscosity * cube(rad) );
 
-    Cytosim::log("Sphere of radius %.3f has mobility %.2e\n", spRadius, spDrag);
+    //Cytosim::log("Sphere of radius %.3f has mobility %.2e\n", spRadius, spDrag);
 }
 
 
