@@ -297,8 +297,15 @@ PYBIND11_MODULE(cytoplay, m) {
     load_couple_classes(m);
     load_organizer_classes(m);
     
+    declare_lattice(m, (uint8_t)1, "Lattice_uint8");
+    declare_lattice(m, (uint16_t)1, "Lattice_uint16");
+    declare_lattice(m, (uint64_t)1, "Lattice_uint64");
+    declare_lattice(m, (uint32_t)1, "Lattice_uint32");
+    declare_lattice(m, (real)1.0, "Lattice_real");
+    
     /// We declare object groups
     // We can later add additional def to any of these groups
+    //auto fibs = declare_group(m, ObjGroup<Fiber,FiberProp>(), ObjVec<Fiber>(), "FiberGroup");
     auto fibs = declare_group(m, ObjGroup<Fiber,FiberProp>(), "FiberGroup");
     auto sols = declare_group(m, ObjGroup<Solid,SolidProp>(), "SolidGroup");
     auto spas = declare_group(m, ObjGroup<Space,SpaceProp>(), "SpaceGroup");
@@ -309,8 +316,8 @@ PYBIND11_MODULE(cytoplay, m) {
     auto cous = declare_group(m, ObjGroup<Couple,CoupleProp>(), "CoupleGroup");
 
     /// Python interface to play/start a simulation
-    m.def("open", &open, "@PYD;C:PyCytosim;T:loads simulation from object files", py::return_value_policy::reference);
-    m.def("start", &start, "@PYD;C:PyCytosim;T:loads simulation from config files", py::return_value_policy::reference);
+    m.def("open", &open, "@PYD;C:PyCytosim;T:loads simulation from object files", PYREF);
+    m.def("start", &start, "@PYD;C:PyCytosim;T:loads simulation from config files", PYREF);
     m.def("str_to_glos", &str_to_glos, "@PYD;C:PyCytosim;T:converts string to Glossary");
     m.def("play", [](py::args args) {
         int nargs = args.size();
