@@ -51,7 +51,6 @@
 #include "pycytosim.h"
 
 namespace py = pybind11;
-void gonna_callback(void) {};
 
 /**
  * @brief Open the simulation from the .cmo files
@@ -143,21 +142,24 @@ PythonParser * start(std::string fname) {
  */
 PYBIND11_MODULE(cytosim, m) {
     m.doc() = 
-				"import cytosim"
-				"sim = cytosim.open() \n"
+				"import cytosim \n"
+				"parser = cytosim.open() \n"
+                "sim = parser.simul \n"
                 "sim.prop.timestep \n"
-                "frame = cytosim.load(0) \n"
+                "parser.load(0) \n"
+                "frame = parser.frame() \n"
                 "fibers = frame['microtubule'] \n"
                 "print(len(fibers)) \n"
-                "while frame.loaded: \n"
-                "    print(frame.time) \n"
-                "    frame = frame.next()"
+                "while parser.next(): \n"
+                "    print(sim.time()) \n"
+                " \n"
                 "# --- OR --- \n"
-                "sim = cytosim.start('cym/aster.cym') \n"
-                "frame = sim.frame() \n"
-                "sim.fibers \n"
-                "fibers[0].join(fibers[1])    # <- Yes, yes, yes. \n"
-                "sim.run(10) \n"; // optional module docstring
+                " \n"
+                "parser = cytosim.start('cym/aster.cym') \n"
+                "sim = parser.simul \n"
+                "fibers = sim.fibers \n"
+                "fibers[0].join(fibers[1]) \n"
+                "parser.run(10) \n"; // optional module docstring
     
     /// Loading properties into the module
     load_thread_classes(m);
@@ -177,6 +179,7 @@ PYBIND11_MODULE(cytosim, m) {
     
     /// We declare object groups
     // We can later add additional def to any of these groups
+    //auto fibs = declare_group(m, ObjGroup<Fiber,FiberProp>(), ObjVec<Fiber>(), "Fiber");
     auto fibs = declare_group(m, ObjGroup<Fiber,FiberProp>(), "FiberGroup");
     auto sols = declare_group(m, ObjGroup<Solid,SolidProp>(), "SolidGroup");
     auto spas = declare_group(m, ObjGroup<Space,SpaceProp>(), "SpaceGroup");
@@ -186,11 +189,15 @@ PYBIND11_MODULE(cytosim, m) {
     auto sins = declare_group(m, ObjGroup<Single,SingleProp>(), "SingleGroup");
     auto cous = declare_group(m, ObjGroup<Couple,CoupleProp>(), "CoupleGroup");
     
-  
+    declare_lattice(m, (uint8_t)1, "Lattice_uint8");
+    declare_lattice(m, (uint16_t)1, "Lattice_uint16");
+    declare_lattice(m, (uint64_t)1, "Lattice_uint64");
+    declare_lattice(m, (uint32_t)1, "Lattice_uint32");
+    declare_lattice(m, (real)1.0, "Lattice_real");
     
     /// Opens the simulation from *.cmo files
-    m.def("open", &open, "@PYD;C:PyCytosim;T:loads simulation from object files", py::return_value_policy::reference);
-    m.def("start", &start, "@PYD;C:PyCytosim;T:loads simulation from config files", py::return_value_policy::reference);
+    m.def("open", &open, "@PYD;C:PyCytosim;T:loads simulation from object files", PYREF);
+    m.def("start", &start, "@PYD;C:PyCytosim;T:loads simulation from config files", PYREF);
     m.def("str_to_glos", &str_to_glos, "@PYD;C:PyCytosim;T:converts string to Glossary");
 
 
