@@ -27,10 +27,11 @@
 #include "object_modules.h"
 #include "hand_modules.h"
 #include "glossary_modules.h"
+#include "lattice_modules.h"
 #include <functional>
+
 namespace py = pybind11;
 
-void bar(void);
 class SimThread;
 
 #endif
